@@ -23,6 +23,9 @@ void Update_Mu_given_QA_full(em_phyclust_struct *empcs, Q_matrix_array *QA, Q_ma
 			}
 
 			for(n_X = 0; n_X < N_X; n_X++){
+				if(empcs->X[n_X][l] == MISSING_ALLELE){
+					continue;
+				}
 				if(empcs->replication_X[n_X] == 1){
 					z_k[empcs->X[n_X][l]] += empcs->Z_normalized[n_X][k];
 				} else{
@@ -62,6 +65,9 @@ void Update_Mu_given_QA_full(em_phyclust_struct *empcs, Q_matrix_array *QA, Q_ma
 			 * such as computing likelihood, finding Mu. */
 			if(flag){
 				for(n_X = 0; n_X < N_X; n_X++){
+					if(empcs->X[n_X][l] == MISSING_ALLELE){
+						continue;
+					}
 					empcs->count_Mu_X[n_X][k][org_s_mu][empcs->X[n_X][l]]--;
 					empcs->count_Mu_X[n_X][k][empcs->Mu[k][l]][empcs->X[n_X][l]]++;
 				}
@@ -85,6 +91,9 @@ void Update_Mu_given_QA_skip_non_seg(em_phyclust_struct *empcs, Q_matrix_array *
 			}
 
 			for(n_X = 0; n_X < N_X; n_X++){
+				if(empcs->X[n_X][l] == MISSING_ALLELE){
+					continue;
+				}
 				if(empcs->replication_X[n_X] == 1){
 					z_k[empcs->X[n_X][l]] += empcs->Z_normalized[n_X][k];
 				} else{
@@ -124,6 +133,9 @@ void Update_Mu_given_QA_skip_non_seg(em_phyclust_struct *empcs, Q_matrix_array *
 			 * such as computing likelihood, finding Mu. */
 			if(flag){
 				for(n_X = 0; n_X < N_X; n_X++){
+					if(empcs->X[n_X][l] == MISSING_ALLELE){
+						continue;
+					}
 					empcs->count_Mu_X[n_X][k][org_s_mu][empcs->X[n_X][l]]--;
 					empcs->count_Mu_X[n_X][k][empcs->Mu[k][l]][empcs->X[n_X][l]]++;
 				}
@@ -133,32 +145,35 @@ void Update_Mu_given_QA_skip_non_seg(em_phyclust_struct *empcs, Q_matrix_array *
 } /* End of Update_Mu_given_QA_skip_non_seg(). */
 
 
-/* Missing version: This function will update Mu given QA for full length sequences. */
-void Update_Mu_given_QA_full_missing(em_phyclust_struct *empcs, Q_matrix_array *QA, Q_matrix_array *QA_H){
+/* GAP version: This function will update Mu given QA for full length sequences. */
+void Update_Mu_given_QA_full_gap(em_phyclust_struct *empcs, Q_matrix_array *QA, Q_matrix_array *QA_H){
 	int org_s_mu, new_s_mu, n_X, k, l, flag = 0;
 	int K = empcs->K, L = empcs->L, Ncode = empcs->ncode, N_X = empcs->N_X;
-	double tmp_psi_k, psi_k[empcs->ncode], z_k[empcs->ncode], z_k_missing;
+	double tmp_psi_k, psi_k[empcs->ncode], z_k[empcs->ncode], z_k_gap;
 
 	for(k = 0; k < K; k++){
 		for(l = 0; l < L; l++){
 			for(org_s_mu = 0; org_s_mu < Ncode; org_s_mu++){
 				z_k[org_s_mu] = 0.0;
 			}
-			z_k_missing = 0.0;
+			z_k_gap = 0.0;
 
 			for(n_X = 0; n_X < N_X; n_X++){
-				if(empcs->X[n_X][l] != empcs->missing_index){
+				if(empcs->X[n_X][l] == MISSING_ALLELE){
+					continue;
+				}
+				if(empcs->X[n_X][l] != empcs->gap_index){
 					if(empcs->replication_X[n_X] == 1){
 						z_k[empcs->X[n_X][l]] += empcs->Z_normalized[n_X][k];
 					} else{
 						z_k[empcs->X[n_X][l]] += empcs->Z_normalized[n_X][k] *
 							empcs->replication_X[n_X];
 					}
-				} else{	/* For missing. */
+				} else{	/* For gap. */
 					if(empcs->replication_X[n_X] == 1){
-						z_k_missing += empcs->Z_normalized[n_X][k];
+						z_k_gap += empcs->Z_normalized[n_X][k];
 					} else{
-						z_k_missing += empcs->Z_normalized[n_X][k] * empcs->replication_X[n_X];
+						z_k_gap += empcs->Z_normalized[n_X][k] * empcs->replication_X[n_X];
 					}
 				}
 			}
@@ -168,7 +183,7 @@ void Update_Mu_given_QA_full_missing(em_phyclust_struct *empcs, Q_matrix_array *
 				for(new_s_mu = 0; new_s_mu < Ncode; new_s_mu++){
 					psi_k[org_s_mu] += z_k[new_s_mu] * QA->Q[k]->log_Pt[org_s_mu][new_s_mu];
 				}
-				psi_k[org_s_mu] += z_k_missing * QA_H->Q[k]->H[org_s_mu];	/* For missing. */
+				psi_k[org_s_mu] += z_k_gap * QA_H->Q[k]->H[org_s_mu];	/* For gap. */
 			}
 
 			org_s_mu = empcs->Mu[k][l];
@@ -185,27 +200,30 @@ void Update_Mu_given_QA_full_missing(em_phyclust_struct *empcs, Q_matrix_array *
 				}
 			}
 
-			/* Dynamically update empcs->count_Mu_X: See non-missing version for details. */
+			/* Dynamically update empcs->count_Mu_X: See non-gap version for details. */
 			if(flag){
 				for(n_X = 0; n_X < N_X; n_X++){
-					if(empcs->X[n_X][l] != empcs->missing_index){
+					if(empcs->X[n_X][l] == MISSING_ALLELE){
+						continue;
+					}
+					if(empcs->X[n_X][l] != empcs->gap_index){
 						empcs->count_Mu_X[n_X][k][org_s_mu][empcs->X[n_X][l]]--;
 						empcs->count_Mu_X[n_X][k][empcs->Mu[k][l]][empcs->X[n_X][l]]++;
-					} else{	/* For missing. */
-						empcs->count_Mu_X_missing[n_X][k][org_s_mu]--;
-						empcs->count_Mu_X_missing[n_X][k][empcs->Mu[k][l]]++;
+					} else{	/* For gap. */
+						empcs->count_Mu_X_gap[n_X][k][org_s_mu]--;
+						empcs->count_Mu_X_gap[n_X][k][empcs->Mu[k][l]]++;
 					}
 				}
 			}
 		}
 	}
-} /* End of Update_Mu_given_QA_missing(). */
+} /* End of Update_Mu_given_QA_gap(). */
 
-/* Missing version: This function will update Mu given QA, but skip non-segregating sites. */
-void Update_Mu_given_QA_skip_non_seg_missing(em_phyclust_struct *empcs, Q_matrix_array *QA, Q_matrix_array *QA_H){
+/* GAP version: This function will update Mu given QA, but skip non-segregating sites. */
+void Update_Mu_given_QA_skip_non_seg_gap(em_phyclust_struct *empcs, Q_matrix_array *QA, Q_matrix_array *QA_H){
 	int org_s_mu, new_s_mu, n_X, k, l, i, flag = 0;
 	int K = empcs->K, N_seg_site = empcs->N_seg_site, Ncode = empcs->ncode, N_X = empcs->N_X;
-	double tmp_psi_k, psi_k[empcs->ncode], z_k[empcs->ncode], z_k_missing;
+	double tmp_psi_k, psi_k[empcs->ncode], z_k[empcs->ncode], z_k_gap;
 
 	for(k = 0; k < K; k++){
 		for(i = 0; i < N_seg_site; i++){
@@ -214,21 +232,24 @@ void Update_Mu_given_QA_skip_non_seg_missing(em_phyclust_struct *empcs, Q_matrix
 			for(org_s_mu = 0; org_s_mu < Ncode; org_s_mu++){
 				z_k[org_s_mu] = 0.0;
 			}
-			z_k_missing = 0.0;
+			z_k_gap = 0.0;
 
 			for(n_X = 0; n_X < N_X; n_X++){
-				if(empcs->X[n_X][l] != empcs->missing_index){
+				if(empcs->X[n_X][l] == MISSING_ALLELE){
+					continue;
+				}
+				if(empcs->X[n_X][l] != empcs->gap_index){
 					if(empcs->replication_X[n_X] == 1){
 						z_k[empcs->X[n_X][l]] += empcs->Z_normalized[n_X][k];
 					} else{
 						z_k[empcs->X[n_X][l]] += empcs->Z_normalized[n_X][k] *
 							empcs->replication_X[n_X];
 					}
-				} else{	/* For missing. */
+				} else{	/* For gap. */
 					if(empcs->replication_X[n_X] == 1){
-						z_k_missing += empcs->Z_normalized[n_X][k];
+						z_k_gap += empcs->Z_normalized[n_X][k];
 					} else{
-						z_k_missing += empcs->Z_normalized[n_X][k] * empcs->replication_X[n_X];
+						z_k_gap += empcs->Z_normalized[n_X][k] * empcs->replication_X[n_X];
 					}
 				}
 			}
@@ -238,7 +259,7 @@ void Update_Mu_given_QA_skip_non_seg_missing(em_phyclust_struct *empcs, Q_matrix
 				for(new_s_mu = 0; new_s_mu < Ncode; new_s_mu++){
 					psi_k[org_s_mu] += z_k[new_s_mu] * QA->Q[k]->log_Pt[org_s_mu][new_s_mu];
 				}
-				psi_k[org_s_mu] += z_k_missing * QA_H->Q[k]->H[org_s_mu];	/* For missing. */
+				psi_k[org_s_mu] += z_k_gap * QA_H->Q[k]->H[org_s_mu];	/* For gap. */
 			}
 
 			org_s_mu = empcs->Mu[k][l];
@@ -255,21 +276,24 @@ void Update_Mu_given_QA_skip_non_seg_missing(em_phyclust_struct *empcs, Q_matrix
 				}
 			}
 
-			/* Dynamically update empcs->count_Mu_X: See non-missing version for details. */
+			/* Dynamically update empcs->count_Mu_X: See non-gap version for details. */
 			if(flag){
 				for(n_X = 0; n_X < N_X; n_X++){
-					if(empcs->X[n_X][l] != empcs->missing_index){
+					if(empcs->X[n_X][l] == MISSING_ALLELE){
+						continue;
+					}
+					if(empcs->X[n_X][l] != empcs->gap_index){
 						empcs->count_Mu_X[n_X][k][org_s_mu][empcs->X[n_X][l]]--;
 						empcs->count_Mu_X[n_X][k][empcs->Mu[k][l]][empcs->X[n_X][l]]++;
-					} else{	/* For missing. */
-						empcs->count_Mu_X_missing[n_X][k][org_s_mu]--;
-						empcs->count_Mu_X_missing[n_X][k][empcs->Mu[k][l]]++;
+					} else{	/* For gap. */
+						empcs->count_Mu_X_gap[n_X][k][org_s_mu]--;
+						empcs->count_Mu_X_gap[n_X][k][empcs->Mu[k][l]]++;
 					}
 				}
 			}
 		}
 	}
-} /* End of Update_Mu_given_QA_skip_non_seg_missing(). */
+} /* End of Update_Mu_given_QA_skip_non_seg_gap(). */
 
 
 
@@ -297,7 +321,7 @@ double Compute_R(em_phyclust_struct *empcs, Q_matrix_array *QA, Q_matrix_array *
 	return(ret);
 } /* End of Compute_R(). */
 
-double Compute_R_missing(em_phyclust_struct *empcs, Q_matrix_array *QA, Q_matrix_array *QA_H){
+double Compute_R_gap(em_phyclust_struct *empcs, Q_matrix_array *QA, Q_matrix_array *QA_H){
 	int n_X, k, s_from;
 	double ret = 0.0, tmp_ret, H_modified;
 
@@ -309,7 +333,7 @@ double Compute_R_missing(em_phyclust_struct *empcs, Q_matrix_array *QA, Q_matrix
 			 * equal to log and unnormalized, the log likelihood for kth component for the n_X sequence. */
 			H_modified = 0.0;
 			for(s_from = 0; s_from < empcs->ncode; s_from++){
-				H_modified += QA_H->Q[k]->H[s_from] * empcs->count_Mu_X_missing[n_X][k][s_from];
+				H_modified += QA_H->Q[k]->H[s_from] * empcs->count_Mu_X_gap[n_X][k][s_from];
 			}
 			tmp_ret += empcs->Z_normalized[n_X][k] * (empcs->Z_modified[n_X][k] + H_modified);
 		}
@@ -321,7 +345,7 @@ double Compute_R_missing(em_phyclust_struct *empcs, Q_matrix_array *QA, Q_matrix
 	}
 
 	return(ret);
-} /* End of Compute_R_missing(). */
+} /* End of Compute_R_gap(). */
 
 
 
